==> dotnet8_8.0.115-8.0.15.orig.tar.xz: src/razor/src/Razor/src/Microsoft.VisualStudio.LanguageServer.ContainedLanguage/VisualStudioTextChange.cs <==
﻿// Copyright (c) .NET Foundation. All rights reserved.
// Licensed under the MIT license. See License.txt in the project root for license information.

using System;
using Microsoft.VisualStudio.LanguageServer.Protocol;
using Microsoft.VisualStudio.Text;

namespace Microsoft.VisualStudio.LanguageServer.ContainedLanguage;

internal class VisualStudioTextChange : ITextChange
{
    public VisualStudioTextChange(int oldStart, int oldLength, string newText)
    {
        OldSpan = new Span(oldStart, oldLength);
        NewText = newText;
    }

    public VisualStudioTextChange(TextEdit textEdit, ITextSnapshot textSnapshot)
    {
        var startRange = textEdit.Range.Start;
        var startLine = textSnapshot.GetLineFromLineNumber(startRange.Line);
        var startAbsoluteIndex = startLine.Start + startRange.Character;
        var endRange = textEdit.Range.End;
        var endLine = textSnapshot.GetLineFromLineNumber(endRange.Line);
        var endAbsoluteIndex = endLine.Start + endRange.Character;
        var length = endAbsoluteIndex - startAbsoluteIndex;
        OldSpan = new Span(startAbsoluteIndex, length);
        NewText = textEdit.NewText;
    }

    public Span OldSpan { get; }
    public int OldPosition => OldSpan.Start;
    public int OldEnd => OldSpan.End;
    public int OldLength => OldSpan.Length;
    public string NewText { get; }
    public int NewLength => NewText.Length;

    public Span NewSpan => throw new NotImplementedException();

    public int NewPosition => throw new NotImplementedException();
    public int Delta => throw new NotImplementedException();
    public int NewEnd => throw new NotImplementedException();
    public string OldText => throw new NotImplementedException();
    public int LineCountDelta => throw new NotImplementedException();

    public override string ToString()
    {
        return OldSpan.ToString() + "->" + NewText;
    }
}

==> dotnet10_10.0.100-10.0.0~rc1.orig.tar.xz: src/razor/src/Razor/src/Microsoft.VisualStudio.LanguageServer.ContainedLanguage/VisualStudioTextChange.cs <==
﻿// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

using System;
using Microsoft.VisualStudio.LanguageServer.Protocol;
using Microsoft.VisualStudio.Text;

namespace Microsoft.VisualStudio.LanguageServer.ContainedLanguage;

internal class VisualStudioTextChange : ITextChange
{
    public VisualStudioTextChange(int oldStart, int oldLength, string newText)
    {
        OldSpan = new Span(oldStart, oldLength);
        NewText = newText;
    }

    public VisualStudioTextChange(TextEdit textEdit, ITextSnapshot textSnapshot)
        : this(
            textEdit.Range.Start.Line,
            textEdit.Range.Start.Character,
            textEdit.Range.End.Line,
            textEdit.Range.End.Character,
            textSnapshot,
            textEdit.NewText)
    {
    }

    public VisualStudioTextChange(int startLineNumber, int startCharacter, int endLineNumber, int endCharacter, ITextSnapshot textSnapshot, string newText)
    {
        var startLine = textSnapshot.GetLineFromLineNumber(startLineNumber);
        var startAbsoluteIndex = startLine.Start + startCharacter;
        var endLine = textSnapshot.GetLineFromLineNumber(endLineNumber);
        var endAbsoluteIndex = endLine.Start + endCharacter;
        var length = endAbsoluteIndex - startAbsoluteIndex;
        OldSpan = new Span(startAbsoluteIndex, length);
        NewText = newText;
    }

    public Span OldSpan { get; }
    public int OldPosition => OldSpan.Start;
    public int OldEnd => OldSpan.End;
    public int OldLength => OldSpan.Length;
    public string NewText { get; }
    public int NewLength => NewText.Length;

    public Span NewSpan => throw new NotImplementedException();

    public int NewPosition => throw new NotImplementedException();
    public int Delta => throw new NotImplementedException();
    public int NewEnd => throw new NotImplementedException();
    public string OldText => throw new NotImplementedException();
    public int LineCountDelta => throw new NotImplementedException();

    public override string ToString()
    {
        return OldSpan.ToString() + "->" + NewText;
    }
}
